@@ -21,6 +21,9 @@ import traceback
 
 
 import logging
+
+from .utils import get_source
+
 logger = logging.getLogger("__core__")
 
 from .providers import exceptions_dumpers_factory
@@ -119,7 +122,7 @@ class Rule:
 
         from .providers import proc_events_rx_factory
 
-        proc_events_rx = proc_events_rx_factory  # one event for each processed rule
+        proc_events_rx = proc_events_rx_factory()  # one event for each processed rule
 
         process_id = str(uuid4())
         procevents_level = int(os.environ.get("PUBLISH_PROCEVENTS_LEVEL", ProcEventsLevel.DISABLED))
@@ -136,7 +139,8 @@ class Rule:
                 Const.PROCESSING: [],
                 Const.GOT_ERRORS: False,
                 Const.EVENT_INFO: event_info,
-                Const.SOURCE: os.environ.get("K_SERVICE", os.environ.get("SOURCE")),
+                Const.SOURCE: get_source()
+                # DEPRECATED use event_info.get("source")
             }
             if procevents_level == ProcEventsLevel.FULL:
                 last_payload = __copy(payload)
